==> stack-2.9.1-187-x86_64.pkg.tar.zst: usr/share/haskell/register/stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.1
visibility:           public
id:                   stack-2.9.1-30tL5IXIprC36kmRyatZjA
key:                  stack-2.9.1-30tL5IXIprC36kmRyatZjA
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  1ab33779391b2fcb478cc5c35410a834
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:       Path.Extended Stack.Types.Cache System.Uname
import-dirs:          /usr/lib/ghc-9.4.8/site-local/stack-2.9.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stack-2.9.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stack-2.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.1-30tL5IXIprC36kmRyatZjA
depends:
    Cabal-3.8.1.0 aeson-2.1.2.1-H9spCVKCz3aBZuysSTfrjv
    annotated-wl-pprint-0.7.0-Bbb9GOQJoVZEpSwInbNN3i
    ansi-terminal-1.0.2-6TxOAUbfOQrDbPnWIRhRhS array-0.5.4.0
    async-2.2.5-7zRWRGcsDHK4x7TGVl8w2c
    attoparsec-0.14.4-L0PdW4nkr6mJUEG3ZdEFXH base-4.17.2.1
    base64-bytestring-1.2.1.0-9p4vtkAuTQ4GHdtuHWxZHU
    bytestring-0.11.5.3 casa-client-0.0.2-LEVVd3okKlVzsbY9gB41X
    casa-types-0.0.2-8yVpyFl8YtiAw1qJfVEDPr
    colour-2.3.6-9rTtk69Pc3k5Ik3SUsZeCb
    conduit-1.3.6.1-GHyJy0fEO4I5Y3sMB26bfT
    conduit-extra-1.3.7-IZqbdwWCIVBKlmFf1WuGHS containers-0.6.7
    crypton-1.0.0-DPZJlEmcVd8Aodr5WBuA08
    crypton-conduit-0.2.3-7YlKBMO6IY6IPN36R2epx2 deepseq-1.4.8.0
    directory-1.3.7.1 echo-0.1.4-HrG6UGs9bUNIRHTRpjaAQ
    exceptions-0.10.5 extra-1.7.16-G4xNEo2ejjd3lhwl24aWT4
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY
    filelock-0.1.1.7-7lTiqr8xhN2LimBoMNcojw filepath-1.4.2.2
    fsnotify-0.3.0.1-L8M20D0XvqDGuGjxkVrKAk
    generic-deriving-1.14.6-9F6ReTfJt8NCt9RC1WY6wc
    hackage-security-0.6.2.6-JgSnuui6qPw6acxr9excds
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    hi-file-parser-0.1.7.0-BlaeucCv3YYEW5Kn9o8Zc1
    hpack-0.35.2-8A6Zf4V2xsGsa7x8gRL7x hpc-0.6.1.0
    http-client-0.7.18-163W4AHWMZxiWwErxEeuv
    http-client-tls-0.3.6.4-2oeYpKUjUcFHV14IdzgHEG
    http-conduit-2.3.9.1-2VtLjWep4YeKVkDI8tAnKo
    http-download-0.2.1.0-92yVPAaUbU99dpN0dyhKpk
    http-types-0.12.4-HMggM4fmSOHB2iuVefoAXW
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    mintty-0.1.4-AuJ2EgpOQbhHDGkFzZNT4J
    mono-traversable-1.0.21.0-EWVducjJ9EF359wA2eNmkP mtl-2.2.2
    mustache-2.4.2-Kbhpt7ZQJHM9mlBqkQFSWX
    neat-interpolation-0.5.1.4-2Sm5WVnJWgf2g2zstohpF9
    network-uri-2.6.4.2-APaQU0Ye6OaKm6pWDY2rCG
    open-browser-0.2.1.1-JxaFXLEqga6LFagqIfuNya
    optparse-applicative-0.17.1.0-4tPjpOfYmOi9nj8To0UB1j
    pantry-0.5.7-314ergKJhyOFjRvIkfNg1k
    path-0.9.5-3cta3v6XNU1LQ20l3qbSA1
    path-io-1.8.2-I95UZMHfEdj6qJgYoqe4Cs
    persistent-2.14.5.1-J18GI72cAlGLRrMTaXyWyv
    persistent-sqlite-2.13.1.0-WZaNwvWpk0HersmtSPRzB pretty-1.1.3.6
    primitive-0.8.0.0-1110YmBHzhAERV5HY7EG3e process-1.6.18.0
    project-template-0.2.1.0-8JwnOdp41yaC9mFvEkaTfT
    random-1.2.1.2-KXwyGxW8gFCDB692Rea4Jy
    retry-0.9.3.1-2kYHOCjSs9LBKcjNRahL80
    rio-0.1.22.0-J3Jrfq68YWeKEgCNothzNm
    rio-prettyprint-0.1.7.0-4bsq76DyoNoJrSlIhRk0r6
    split-0.2.5-KcBaumhT6eFHklJKzsytdC stm-2.5.1.0
    streaming-commons-0.2.3.0-18n0yU3DoS0GNSvBxR5zoS
    tar-0.5.1.1-FbhiFJT9rV7IgMs1cD4nyJ template-haskell-2.19.0.0
    temporary-1.3-8FAts4F1AmtHqh7aYyLCzN text-2.0.2
    text-metrics-0.3.2-GpbdAVN3NA050ijK0xGwoJ
    th-reify-many-0.1.10-KYxOLbz5rL78v9d4nottr7 time-1.12.2
    tls-1.9.0-o0vUsxdxA360IfVVWdacO transformers-0.5.6.2
    typed-process-0.2.13.0-GPI78s871wHEC3iGahod0k
    unicode-transforms-0.4.0.1-J12d8n4btOu6C9M6wuuSUl unix-2.7.3
    unix-compat-0.7.3-APGBQbQVvi2H82Ka3k4LXj
    unliftio-0.2.25.1-4ouS4p8u42FHJEBnZmJiqL
    unordered-containers-0.2.20-L3M6eILO3KM5ipeNJik2xY
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8
    yaml-0.11.11.2-D1kIggkOAtBBnhgc0kzINw
    zip-archive-0.4.3.2-GmNVaBYgl1m3nPxjZ1tNrn
    zlib-0.6.3.0-DQJ3sjglCnhJjpkMXQsJJY

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> stack-2.9.1-188-x86_64.pkg.tar.zst: usr/share/haskell/register/stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.1
visibility:           public
id:                   stack-2.9.1-FVdi9BWFCLA88fuwTUUqph
key:                  stack-2.9.1-FVdi9BWFCLA88fuwTUUqph
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  b4154b288174f9a106a8020ee00c622b
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:       Path.Extended Stack.Types.Cache System.Uname
import-dirs:          /usr/lib/ghc-9.4.8/site-local/stack-2.9.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stack-2.9.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stack-2.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.1-FVdi9BWFCLA88fuwTUUqph
depends:
    Cabal-3.8.1.0 aeson-2.1.2.1-H9spCVKCz3aBZuysSTfrjv
    annotated-wl-pprint-0.7.0-Bbb9GOQJoVZEpSwInbNN3i
    ansi-terminal-1.0.2-6TxOAUbfOQrDbPnWIRhRhS array-0.5.4.0
    async-2.2.5-7zRWRGcsDHK4x7TGVl8w2c
    attoparsec-0.14.4-L0PdW4nkr6mJUEG3ZdEFXH base-4.17.2.1
    base64-bytestring-1.2.1.0-9p4vtkAuTQ4GHdtuHWxZHU
    bytestring-0.11.5.3 casa-client-0.0.2-LKaIDL2ZHDs6pf6tyJjVTW
    casa-types-0.0.2-8yVpyFl8YtiAw1qJfVEDPr
    colour-2.3.6-9rTtk69Pc3k5Ik3SUsZeCb
    conduit-1.3.6.1-GHyJy0fEO4I5Y3sMB26bfT
    conduit-extra-1.3.7-IZqbdwWCIVBKlmFf1WuGHS containers-0.6.7
    crypton-1.0.0-DPZJlEmcVd8Aodr5WBuA08
    crypton-conduit-0.2.3-7YlKBMO6IY6IPN36R2epx2 deepseq-1.4.8.0
    directory-1.3.7.1 echo-0.1.4-HrG6UGs9bUNIRHTRpjaAQ
    exceptions-0.10.5 extra-1.7.16-G4xNEo2ejjd3lhwl24aWT4
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY
    filelock-0.1.1.7-7lTiqr8xhN2LimBoMNcojw filepath-1.4.2.2
    fsnotify-0.3.0.1-L8M20D0XvqDGuGjxkVrKAk
    generic-deriving-1.14.6-9F6ReTfJt8NCt9RC1WY6wc
    hackage-security-0.6.2.6-JgSnuui6qPw6acxr9excds
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    hi-file-parser-0.1.7.0-BlaeucCv3YYEW5Kn9o8Zc1
    hpack-0.35.2-8A6Zf4V2xsGsa7x8gRL7x hpc-0.6.1.0
    http-client-0.7.18-163W4AHWMZxiWwErxEeuv
    http-client-tls-0.3.6.4-2oeYpKUjUcFHV14IdzgHEG
    http-conduit-2.3.9.1-5mE2jwRRrfXKVbYSaoLl7b
    http-download-0.2.1.0-A5aXgYa0WkFFlCDEeqgIhL
    http-types-0.12.4-HMggM4fmSOHB2iuVefoAXW
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    mintty-0.1.4-AuJ2EgpOQbhHDGkFzZNT4J
    mono-traversable-1.0.21.0-EWVducjJ9EF359wA2eNmkP mtl-2.2.2
    mustache-2.4.2-Kbhpt7ZQJHM9mlBqkQFSWX
    neat-interpolation-0.5.1.4-2Sm5WVnJWgf2g2zstohpF9
    network-uri-2.6.4.2-APaQU0Ye6OaKm6pWDY2rCG
    open-browser-0.2.1.1-JxaFXLEqga6LFagqIfuNya
    optparse-applicative-0.17.1.0-4tPjpOfYmOi9nj8To0UB1j
    pantry-0.5.7-AXxoCIP36DhBNd85AAObC1
    path-0.9.5-3cta3v6XNU1LQ20l3qbSA1
    path-io-1.8.2-I95UZMHfEdj6qJgYoqe4Cs
    persistent-2.14.5.1-J18GI72cAlGLRrMTaXyWyv
    persistent-sqlite-2.13.1.0-WZaNwvWpk0HersmtSPRzB pretty-1.1.3.6
    primitive-0.8.0.0-1110YmBHzhAERV5HY7EG3e process-1.6.18.0
    project-template-0.2.1.0-8JwnOdp41yaC9mFvEkaTfT
    random-1.2.1.2-KXwyGxW8gFCDB692Rea4Jy
    retry-0.9.3.1-2kYHOCjSs9LBKcjNRahL80
    rio-0.1.22.0-J3Jrfq68YWeKEgCNothzNm
    rio-prettyprint-0.1.7.0-4bsq76DyoNoJrSlIhRk0r6
    split-0.2.5-KcBaumhT6eFHklJKzsytdC stm-2.5.1.0
    streaming-commons-0.2.3.0-18n0yU3DoS0GNSvBxR5zoS
    tar-0.5.1.1-FbhiFJT9rV7IgMs1cD4nyJ template-haskell-2.19.0.0
    temporary-1.3-8FAts4F1AmtHqh7aYyLCzN text-2.0.2
    text-metrics-0.3.2-GpbdAVN3NA050ijK0xGwoJ
    th-reify-many-0.1.10-KYxOLbz5rL78v9d4nottr7 time-1.12.2
    tls-1.9.0-o0vUsxdxA360IfVVWdacO transformers-0.5.6.2
    typed-process-0.2.13.0-GPI78s871wHEC3iGahod0k
    unicode-transforms-0.4.0.1-J12d8n4btOu6C9M6wuuSUl unix-2.7.3
    unix-compat-0.7.3-APGBQbQVvi2H82Ka3k4LXj
    unliftio-0.2.25.1-4ouS4p8u42FHJEBnZmJiqL
    unordered-containers-0.2.20-L3M6eILO3KM5ipeNJik2xY
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8
    yaml-0.11.11.2-D1kIggkOAtBBnhgc0kzINw
    zip-archive-0.4.3.2-GmNVaBYgl1m3nPxjZ1tNrn
    zlib-0.6.3.0-DQJ3sjglCnhJjpkMXQsJJY

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
